from email.policy import default
from typing import Optional
from fastapi_camelcase import CamelModel
from pydantic import Field


class FmsAddress(CamelModel):
    sa_no: Optional[str] = Field(default=None, alias="saNo")
    resc_cd: Optional[str] = Field(default=None, alias="rescCd")
    sa_house: Optional[str] = Field(default=None, alias="saHouse")
    sa_street_name: Optional[str] = Field(default=None, alias="saStreetName")
    sa_city_province_code: Optional[str] = Field(
        default=None, alias="saCityProvinceCode"
    )
    sa_postal_code: Optional[str] = Field(default="N/A", alias="saPostalCode")
    sa_clli_code: Optional[str] = Field(default=None, alias="saCLLICode")
    serv_coid: Optional[str] = Field(default=None, alias="servCoid")
    sa_clli_prov_cd: Optional[str] = Field(default=None, alias="saClliProvCd")



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel
from pydantic import AnyUrl, Field

from telus_bulk.models.tmf_645.characteristic_relationship import (
    CharacteristicRelationship,
)


class Characteristic(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    Characteristic - a model defined in OpenAPI

        id: The id of this Characteristic [Optional].
        name: The name of this Characteristic.
        value_type: The value_type of this Characteristic [Optional].
        characteristic_relationship: The characteristic_relationship of this Characteristic [Optional].
        value: The value of this Characteristic.
        base_type: The base_type of this Characteristic [Optional].
        schema_location: The schema_location of this Characteristic [Optional].
        type: The type of this Characteristic [Optional].
    """

    id: Optional[str] = None
    name: str
    value_type: Optional[str] = None
    characteristic_relationship: Optional[List[CharacteristicRelationship]] = None
    value: Dict[str, Any]
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")


Characteristic.update_forward_refs()



import typing
import httpx
from loguru import logger
from httpx._types import QueryParamTypes


def http_get(
    base_url: str,
    segment: str = "",
    params: QueryParamTypes = None,
    access_token: str = None,
):
    """
    Fetch get request
    :param base_url: principal domain
    :param segment: request segment
    :param access_token: JWT access token
    :return: JSON response
    """
    headers = {
        "authorization": f"Bearer {access_token}",
    }
    with httpx.Client(
        base_url=base_url, headers=headers, verify=False, timeout=30
    ) as client:
        try:
            r = client.get(url=segment, params=params)
            r.raise_for_status()
        except httpx.HTTPStatusError as exc:
            logger.error(
                f"Error response {exc.response.status_code} while requesting {exc.request.url!r}"
            )
            return None
        except httpx.HTTPError as exc:
            logger.error(f"Error while requesting {exc.request.url!r}")
            return None
    return r.json()


def http_post(
    base_url: str, segment: str = "", data: typing.Optional[dict[str, str]] = None
):
    """
    Fetch post request
    :param base_url: principal domain
    :param segment: request segment
    :param data: request payload
    :return: JSON response
    """
    headers = {"content-type": "application/x-www-form-urlencoded"}
    with httpx.Client(
        base_url=base_url, headers=headers, verify=False, timeout=30
    ) as client:
        try:
            r = client.post(url=segment, data=data)
            r.raise_for_status()
        except httpx.HTTPStatusError as exc:
            logger.error(
                f"Error response {exc.response.status_code} while requesting {exc.request.url}"
            )
            return None
        except httpx.HTTPError as exc:
            logger.error(f"Error while requesting {exc.request.url}")
            return None
    return r.json()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401

from telus_bulk.models.tmf_645.check_service_qualification_state_change_event_payload import (
    CheckServiceQualificationStateChangeEventPayload,
)


class CheckServiceQualificationStateChangeEvent(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    CheckServiceQualificationStateChangeEvent - a model defined in OpenAPI

        event: The event of this CheckServiceQualificationStateChangeEvent [Optional].
        event_id: The event_id of this CheckServiceQualificationStateChangeEvent [Optional].
        event_time: The event_time of this CheckServiceQualificationStateChangeEvent [Optional].
        event_type: The event_type of this CheckServiceQualificationStateChangeEvent [Optional].
        correlation_id: The correlation_id of this CheckServiceQualificationStateChangeEvent [Optional].
        domain: The domain of this CheckServiceQualificationStateChangeEvent [Optional].
        title: The title of this CheckServiceQualificationStateChangeEvent [Optional].
        description: The description of this CheckServiceQualificationStateChangeEvent [Optional].
        priority: The priority of this CheckServiceQualificationStateChangeEvent [Optional].
        time_ocurred: The time_ocurred of this CheckServiceQualificationStateChangeEvent [Optional].
    """

    event: Optional[CheckServiceQualificationStateChangeEventPayload] = None
    event_id: Optional[str] = None
    event_time: Optional[datetime] = None
    event_type: Optional[str] = None
    correlation_id: Optional[str] = None
    domain: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None
    priority: Optional[str] = None
    time_ocurred: Optional[datetime] = None


CheckServiceQualificationStateChangeEvent.update_forward_refs()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field

from telus_bulk.models.tmf_645.related_party import RelatedParty
from telus_bulk.models.tmf_645.service_qualification_item import (
    ServiceQualificationItem,
)


class QueryServiceQualificationCreate(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    QueryServiceQualificationCreate - a model defined in OpenAPI

        description: The description of this QueryServiceQualificationCreate [Optional].
        expected_qualification_date: The expected_qualification_date of this QueryServiceQualificationCreate [Optional].
        external_id: The external_id of this QueryServiceQualificationCreate [Optional].
        instant_sync_qualification: The instant_sync_qualification of this QueryServiceQualificationCreate [Optional].
        related_party: The related_party of this QueryServiceQualificationCreate [Optional].
        search_criteria: The search_criteria of this QueryServiceQualificationCreate.
        base_type: The base_type of this QueryServiceQualificationCreate [Optional].
        schema_location: The schema_location of this QueryServiceQualificationCreate [Optional].
        type: The type of this QueryServiceQualificationCreate [Optional].
    """

    description: Optional[str] = None
    expected_qualification_date: Optional[datetime] = None
    external_id: Optional[str] = None
    instant_sync_qualification: Optional[bool] = None
    related_party: Optional[List[RelatedParty]] = None
    search_criteria: ServiceQualificationItem
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")


QueryServiceQualificationCreate.update_forward_refs()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401

from telus_bulk.models.tmf_645.check_service_qualification import (
    CheckServiceQualification,
)


class CheckServiceQualificationAttributeValueChangeEventPayload(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    CheckServiceQualificationAttributeValueChangeEventPayload - a model defined in OpenAPI

        check_service_qualification: The check_service_qualification of this CheckServiceQualificationAttributeValueChangeEventPayload [Optional].
    """

    check_service_qualification: Optional[CheckServiceQualification] = None


CheckServiceQualificationAttributeValueChangeEventPayload.update_forward_refs()



from typing import Optional

from pydantic import BaseModel  # noqa: F401


class CredentialsResponse(BaseModel):
    access_token: str
    token_type: str
    expires_in: int


CredentialsResponse.update_forward_refs()